@@ -9,9 +9,9 @@ use Complete::Common qw(:all);
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-26'; # DATE
+our $DATE = '2024-01-23'; # DATE
 our $DIST = 'Complete-Util'; # DIST
-our $VERSION = '0.619'; # VERSION
+our $VERSION = '0.620'; # VERSION
 
 our @EXPORT_OK = qw(
                        hashify_answer
@@ -50,7 +50,7 @@ $SPEC{':package'} = {
 
 This package provides some generic completion routines that follow the
 <pm:Complete> convention. (If you are looking for bash/shell tab completion
-routines, take a look at the See Also section.) The main routine is
+routines, take a look at L</"SEE ALSO">.) The main routine is
 `complete_array_elem` which tries to complete a word using choices from elements
 of supplied array. For example:
 
@@ -890,6 +890,7 @@ to return a completion answer.
 _
         },
         uniq => {
+            summary => 'If set to true, then do not offer key that has been mentioned before in the word',
             schema => 'bool*',
             default => 1,
         },
@@ -1189,7 +1190,6 @@ _
     result => {
         schema => 'undef',
     },
-    tags => ['hidden'],
 };
 sub ununiquify_answer {
     my %args = @_;
@@ -1220,14 +1220,14 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.619 of Complete::Util (from Perl distribution Complete-Util), released on 2023-12-26.
+This document describes version 0.620 of Complete::Util (from Perl distribution Complete-Util), released on 2024-01-23.
 
 =head1 DESCRIPTION
 
 
 This package provides some generic completion routines that follow the
 L<Complete> convention. (If you are looking for bash/shell tab completion
-routines, take a look at the See Also section.) The main routine is
+routines, take a look at L</"SEE ALSO">.) The main routine is
 C<complete_array_elem> which tries to complete a word using choices from elements
 of supplied array. For example:
 
@@ -1617,7 +1617,7 @@ and is expected to return remaining elements to offer.
 
 =item * B<uniq> => I<bool> (default: 1)
 
-(No description)
+If set to true, then do not offer key that has been mentioned before in the word.
 
 =item * B<word>* => I<str> (default: "")
 
@@ -1828,6 +1828,34 @@ Arguments ('*' denotes required arguments):
 (No description)
 
 
+=back
+
+Return value:  (undef)
+
+
+
+=head2 ununiquify_answer
+
+Usage:
+
+ ununiquify_answer(%args) -> undef
+
+If answer contains only one item, make it two.
+
+For example, if answer is C<["a"]>, then will make answer become C<["a","a "]>.
+This will prevent shell from automatically adding space.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<answer>* => I<hash|array>
+
+(No description)
+
+
 =back
 
 Return value:  (undef)
@@ -1940,7 +1968,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022, 2020, 2019, 2017, 2016, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2022, 2020, 2019, 2017, 2016, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
